Mentions légales du service

Skip to content
Snippets Groups Projects
Commit 786cb89e authored by Thomas Moulard's avatar Thomas Moulard
Browse files

Add additional patch to fix FreeBSD compilation failure

parent 4d795067
No related branches found
No related tags found
No related merge requests found
......@@ -7,7 +7,7 @@ Remove minor version number from library soversion.
Forwarded: no
Author: Thomas Moulard <thomas.moulard@gmail.com>
---
src/CMakeLists.txt | 2 +-
src/CMakeLists.txt | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/src/CMakeLists.txt b/src/CMakeLists.txt
......
......@@ -9,12 +9,12 @@ Origin: upstream, https://gforge.inria.fr/scm/viewvc.php?view=rev&root=visp&revi
Bug: https://gforge.inria.fr/tracker/index.php?func=detail&aid=15587&group_id=397&atid=1867
Author: Fabien Spindler
---
CMakeLists.txt | 20 ------
CMakeModules/GenerateConfigScript.cmake | 117 +++++++++++++++++++++++++------
CMakeModules/visp-config.in | 4 +-
CMakeModules/visp-config.install.in | 103 +++++++++++++++++++++++++++
CMakeModules/visp.pc.in | 14 ++++
5 files changed, 214 insertions(+), 44 deletions(-)
CMakeLists.txt | 20 ------
CMakeModules/GenerateConfigScript.cmake | 115 ++++++++++++++++++++++++++------
CMakeModules/visp-config.in | 4 +-
CMakeModules/visp-config.install.in | 103 ++++++++++++++++++++++++++++
CMakeModules/visp.pc.in | 14 ++++
5 files changed, 212 insertions(+), 44 deletions(-)
create mode 100644 CMakeModules/visp-config.install.in
create mode 100644 CMakeModules/visp.pc.in
......@@ -50,7 +50,7 @@ index e762c6f..fdcb0b0 100644
#----------------------------------------------------------------------
INCLUDE(${VISP_CMAKE_MODULE_PATH}/TargetDistclean.cmake)
diff --git a/CMakeModules/visp-config.in b/CMakeModules/visp-config.in
index 8a54027..3a45e08 100755
--- a/CMakeModules/visp-config.in
......@@ -262,7 +260,7 @@ index 8a54027..3a45e08 100755
diff --git a/CMakeModules/visp-config.install.in b/CMakeModules/visp-config.install.in
new file mode 100644
index 0000000..88504df
index 0000000..6ec1106
--- /dev/null
+++ b/CMakeModules/visp-config.install.in
@@ -0,0 +1,103 @@
......@@ -274,7 +272,7 @@ index 0000000..88504df
+#
+# This file is part of the ViSP software.
+# Copyright (C) 2005 - 2013 by INRIA. All rights reserved.
+#
+#
+# This software is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License
+# ("GPL") version 2 as published by the Free Software Foundation.
......@@ -282,11 +280,11 @@ index 0000000..88504df
+# distribution for additional information about the GNU GPL.
+#
+# For using ViSP with software that can not be combined with the GNU
+# GPL, please contact INRIA about acquiring a ViSP Professional
+# GPL, please contact INRIA about acquiring a ViSP Professional
+# Edition License.
+#
+# See http://www.irisa.fr/lagadic/visp/visp.html for more information.
+#
+#
+# This software was developed at:
+# INRIA Rennes - Bretagne Atlantique
+# Campus Universitaire de Beaulieu
......@@ -296,13 +294,13 @@ index 0000000..88504df
+#
+# If you have questions regarding the use of this file, please contact
+# INRIA at visp@inria.fr
+#
+#
+# This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
+# WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+#
+# Description:
+# visp-config shell script.
+# Auto-generated from visp-config.install.in by cmake. For backward
+# Auto-generated from visp-config.install.in by cmake. For backward
+# compatibility used visp.pc.
+#
+# Authors:
......@@ -360,7 +358,7 @@ index 0000000..88504df
+ --prefix) echo $NO_NEWLINE_OPTION "$PREFIX$NO_NEWLINE_CHARACTER";;
+ --cflags) echo $NO_NEWLINE_OPTION "$CFLAGS$NO_NEWLINE_CHARACTER";;
+ --libs) echo $NO_NEWLINE_OPTION "$LIBS$NO_NEWLINE_CHARACTER";;
+ --version)
+ --version)
+ echo "ViSP $VERSION (Visual Servoing Platform)"
+ echo ""
+ echo "Copyright (C) 2005 - 2013 Inria. All rights reserved.";;
......
......@@ -9,14 +9,14 @@ Origin: upstream, https://gforge.inria.fr/tracker/?func=detail&atid=1867&aid=156
Bug: https://gforge.inria.fr/tracker/?func=detail&atid=1867&aid=15623&group_id=397
Author: Fabien Spindler
---
src/device/framegrabber/1394/vp1394TwoGrabber.cpp | 5 ++-
src/image/vpImageIo.cpp | 50 ++++++++++++++++++---
src/math/matrix/vpMatrix.cpp | 2 +
src/math/matrix/vpMatrix_svd.cpp | 3 ++
src/math/spline/vpNurbs.cpp | 6 ++-
src/robot/real-robot/afma6/vpAfma6.cpp | 1 -
src/robot/real-robot/viper/vpViper650.cpp | 1 -
src/robot/real-robot/viper/vpViper850.cpp | 1 -
src/device/framegrabber/1394/vp1394TwoGrabber.cpp | 5 ++-
src/image/vpImageIo.cpp | 50 +++++++++++++++++++----
src/math/matrix/vpMatrix.cpp | 2 +
src/math/matrix/vpMatrix_svd.cpp | 3 ++
src/math/spline/vpNurbs.cpp | 6 ++-
src/robot/real-robot/afma6/vpAfma6.cpp | 1 -
src/robot/real-robot/viper/vpViper650.cpp | 1 -
src/robot/real-robot/viper/vpViper850.cpp | 1 -
8 files changed, 56 insertions(+), 13 deletions(-)
diff --git a/src/device/framegrabber/1394/vp1394TwoGrabber.cpp b/src/device/framegrabber/1394/vp1394TwoGrabber.cpp
......
......@@ -7,12 +7,11 @@ Install vpConfig.h in include/<architecture triplet>.
Author: Thomas Moulard <thomas.moulard@gmail.com>
Forwarded: no (not relevant)
---
CMakeLists.txt | 2 +-
CMakeModules/GenerateConfigScript.cmake | 2 +-
2 files changed, 2 insertions(+), 2 deletions(-)
CMakeLists.txt | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/CMakeLists.txt b/CMakeLists.txt
index fdcb0b0..b6f8ac8 100644
index fdcb0b0..78f649b 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -2033,7 +2033,7 @@ EXPORT_LIBRARY_DEPENDENCIES(
......@@ -20,7 +19,7 @@ index fdcb0b0..b6f8ac8 100644
# Install vpConfig.h that may differ from the one in include/visp
INSTALL(FILES ${VISP_BINARY_DIR}/install/vpConfig.h
- DESTINATION ${CMAKE_INSTALL_INCLUDEDIR}/visp
+ DESTINATION ${CMAKE_INSTALL_INCLUDEDIR}/${CMAKE_LIBRARY_ARCHITECTURE}/visp
+ DESTINATION ${CMAKE_INSTALL_INCLUDEDIR}/${CMAKE_LIBRARY_ARCHITECTURE}/visp
PERMISSIONS OWNER_READ GROUP_READ WORLD_READ OWNER_WRITE
COMPONENT headers
)
......@@ -7,25 +7,25 @@ Fix CMake files to support multiarch.
Origin: upstream, private communication.
Author: Fabien Spindler <fabien.spindler@inria.fr>
---
CMakeLists.txt | 31 +++++++++++--------------------
CMakeModules/VISPConfig.cmake.in | 3 ---
distclean.sh | 1 -
CMakeLists.txt | 31 +++++++++++--------------------
CMakeModules/VISPConfig.cmake.in | 3 ---
distclean.sh | 1 -
3 files changed, 11 insertions(+), 24 deletions(-)
diff --git a/CMakeLists.txt b/CMakeLists.txt
index b6f8ac8..a6810c2 100644
index 78f649b..591470e 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -1952,9 +1952,10 @@ ADD_CUSTOM_TARGET(uninstall
set(VISP_ROOT_DIR_CONFIGCMAKE "${VISP_BINARY_DIR}")
set(VISP_ROOT_DIR_CMAKE_CONFIGCMAKE "${VISP_BINARY_DIR}")
+set(VISP_ROOT_DIR_DATA_CONFIGCMAKE "${VISP_BINARY_DIR}")
+set(VISP_ROOT_DIR_DATA_CONFIGCMAKE "${VISP_BINARY_DIR}")
-SET(VISP_SCENES_DIR ${VISP_ROOT_DIR_CMAKE_CONFIGCMAKE}/data/wireframe-simulator)
-SET(VISP_ROBOT_ARMS_DIR ${VISP_ROOT_DIR_CMAKE_CONFIGCMAKE}/data/robot-simulator)
+SET(VISP_SCENES_DIR ${VISP_ROOT_DIR_DATA_CONFIGCMAKE}/data/wireframe-simulator)
+SET(VISP_ROBOT_ARMS_DIR ${VISP_ROOT_DIR_DATA_CONFIGCMAKE}/data/robot-simulator)
+SET(VISP_SCENES_DIR ${VISP_ROOT_DIR_DATA_CONFIGCMAKE}/data/wireframe-simulator)
+SET(VISP_ROBOT_ARMS_DIR ${VISP_ROOT_DIR_DATA_CONFIGCMAKE}/data/robot-simulator)
# Generate the package dependent file include/visp/vpConfig.h
CONFIGURE_FILE(${VISP_SOURCE_DIR}/include/vpConfig.h.cmake
......@@ -47,26 +47,26 @@ index b6f8ac8..a6810c2 100644
set(VISP_ROOT_DIR_CONFIGCMAKE "${CMAKE_INSTALL_PREFIX}")
IF(UNIX)
- set(VISP_ROOT_DIR_CMAKE_CONFIGCMAKE "${CMAKE_INSTALL_PREFIX}/${CMAKE_INSTALL_DATAROOTDIR}/visp")
+ set(VISP_ROOT_DIR_CMAKE_CONFIGCMAKE "${CMAKE_INSTALL_PREFIX}/${CMAKE_INSTALL_LIBDIR}/visp")
+ set(VISP_ROOT_DIR_DATA_CONFIGCMAKE "${CMAKE_INSTALL_PREFIX}/${CMAKE_INSTALL_DATAROOTDIR}/visp")
+ set(VISP_ROOT_DIR_CMAKE_CONFIGCMAKE "${CMAKE_INSTALL_PREFIX}/${CMAKE_INSTALL_LIBDIR}/visp")
+ set(VISP_ROOT_DIR_DATA_CONFIGCMAKE "${CMAKE_INSTALL_PREFIX}/${CMAKE_INSTALL_DATAROOTDIR}/visp")
ELSE()
set(VISP_ROOT_DIR_CMAKE_CONFIGCMAKE "${CMAKE_INSTALL_PREFIX}")
+ set(VISP_ROOT_DIR_DATA_CONFIGCMAKE "${CMAKE_INSTALL_PREFIX}")
+ set(VISP_ROOT_DIR_DATA_CONFIGCMAKE "${CMAKE_INSTALL_PREFIX}")
ENDIF()
-SET(VISP_SCENES_DIR ${VISP_ROOT_DIR_CMAKE_CONFIGCMAKE}/data/wireframe-simulator)
-SET(VISP_ROBOT_ARMS_DIR ${VISP_ROOT_DIR_CMAKE_CONFIGCMAKE}/data/robot-simulator)
+SET(VISP_SCENES_DIR ${VISP_ROOT_DIR_DATA_CONFIGCMAKE}/data/wireframe-simulator)
+SET(VISP_ROBOT_ARMS_DIR ${VISP_ROOT_DIR_DATA_CONFIGCMAKE}/data/robot-simulator)
+SET(VISP_SCENES_DIR ${VISP_ROOT_DIR_DATA_CONFIGCMAKE}/data/wireframe-simulator)
+SET(VISP_ROBOT_ARMS_DIR ${VISP_ROOT_DIR_DATA_CONFIGCMAKE}/data/robot-simulator)
# Only if resources.cfg created by hand, we change the path to resources.cfg in install/vpConfig.h
if(VISP_INSTALL_DIR_OGRE_RESOURCES)
- SET(VISP_HAVE_OGRE_RESOURCES_PATH ${VISP_ROOT_DIR_CMAKE_CONFIGCMAKE}/data/ogre-simulator)
+ SET(VISP_HAVE_OGRE_RESOURCES_PATH ${VISP_ROOT_DIR_DATA_CONFIGCMAKE}/data/ogre-simulator)
+ SET(VISP_HAVE_OGRE_RESOURCES_PATH ${VISP_ROOT_DIR_DATA_CONFIGCMAKE}/data/ogre-simulator)
endif()
# Only if plugins.cfg created by hand, we change the path to plugins.cfg in install/vpConfig.h
if(VISP_INSTALL_DIR_OGRE_RESOURCES)
- SET(VISP_HAVE_OGRE_PLUGINS_PATH ${VISP_ROOT_DIR_CMAKE_CONFIGCMAKE}/data/ogre-simulator)
+ SET(VISP_HAVE_OGRE_PLUGINS_PATH ${VISP_ROOT_DIR_DATA_CONFIGCMAKE}/data/ogre-simulator)
+ SET(VISP_HAVE_OGRE_PLUGINS_PATH ${VISP_ROOT_DIR_DATA_CONFIGCMAKE}/data/ogre-simulator)
endif()
# Generate the package dependent file include/visp/vpConfig.h
......@@ -87,7 +87,7 @@ index b6f8ac8..a6810c2 100644
- ${VISP_BINARY_DIR}/install/VISPLibraryDepends.cmake
- ${VISP_BINARY_DIR}/ViSP-third-party.txt
- DESTINATION ${CMAKE_INSTALL_DATAROOTDIR}/visp
+ DESTINATION ${CMAKE_INSTALL_LIBDIR}/visp
+ DESTINATION ${CMAKE_INSTALL_LIBDIR}/visp
PERMISSIONS OWNER_READ GROUP_READ WORLD_READ OWNER_WRITE
COMPONENT libraries
)
......
......@@ -8,11 +8,11 @@ Author: Thomas Moulard <thomas.moulard@gmail.com>
Bug: https://gforge.inria.fr/tracker/index.php?func=detail&aid=15896&group_id=397&atid=1867
Forwarded: yes
---
CMakeLists.txt | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
CMakeLists.txt | 3 +--
1 file changed, 1 insertion(+), 2 deletions(-)
diff --git a/CMakeLists.txt b/CMakeLists.txt
index a6810c2..e252aa8 100644
index 591470e..aaa4c8d 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -725,7 +725,7 @@ IF(USE_OGRE)
......@@ -20,11 +20,11 @@ index a6810c2..e252aa8 100644
set(Boost_ADDITIONAL_VERSIONS "1.53.0" "1.52.0" "1.51.0" "1.50.0" "1.49.0" "1.48.0" "1.47.0" "1.46.0" "1.45.0" "1.44.0" "1.44" "1.44.0" "1.42" "1.42.0" "1.41.0" "1.41" "1.40.0" "1.40" "1.39.0" "1.39" "1.38.0" "1.38" "1.37.0" "1.37" )
# Components that need linking (NB does not include header-only components like bind)
- set(OGRE_BOOST_COMPONENTS thread date_time)
+ set(OGRE_BOOST_COMPONENTS thread date_time system)
+ set(OGRE_BOOST_COMPONENTS thread date_time system)
find_package(Boost COMPONENTS ${OGRE_BOOST_COMPONENTS} QUIET)
mark_as_advanced(Boost_LIB_DIAGNOSTIC_DEFINITIONS Boost_DIR)
if (NOT Boost_FOUND)
@@ -733,7 +733,6 @@
@@ -733,7 +733,6 @@ IF(USE_OGRE)
set(Boost_USE_STATIC_LIBS NOT ${Boost_USE_STATIC_LIBS})
find_package(Boost COMPONENTS ${OGRE_BOOST_COMPONENTS} QUIET)
endif()
......
From: Thomas Moulard <thomas.moulard@gmail.com>
Date: Fri, 12 Jul 2013 16:10:46 +0900
Subject: Fix compilation error on FreeBSD
---
src/tools/io/vpKeyboard.cpp | 6 +++---
1 file changed, 3 insertions(+), 3 deletions(-)
diff --git a/src/tools/io/vpKeyboard.cpp b/src/tools/io/vpKeyboard.cpp
index 429e6c5..c79eb43 100644
--- a/src/tools/io/vpKeyboard.cpp
+++ b/src/tools/io/vpKeyboard.cpp
@@ -136,10 +136,10 @@ vpKeyboard::setRawMode(bool active)
new_settings.c_lflag &= (unsigned int)~ICANON;
new_settings.c_lflag &= (unsigned int)~ECHO;
new_settings.c_lflag &= (unsigned int)~ISIG;
- new_settings.c_oflag &= (unsigned int)~NL0;
- new_settings.c_oflag &= (unsigned int)~CR0;
+ //new_settings.c_oflag &= (unsigned int)~NL0;
+ //new_settings.c_oflag &= (unsigned int)~CR0;
new_settings.c_oflag &= (unsigned int)~TAB0;
- new_settings.c_oflag &= (unsigned int)~BS0;
+ //new_settings.c_oflag &= (unsigned int)~BS0;
new_settings.c_cc[VMIN] = 1;
new_settings.c_cc[VTIME] = 0;
tcsetattr(STDIN_FILENO, TCSANOW, &new_settings);
......@@ -4,3 +4,4 @@
0004-Install-vpConfig.h-in-include-architecture-triplet.patch
0005-Fix-CMake-files-to-support-multiarch.patch
0006-Look-for-and-compile-against-Boost.System-in-CMakeLi.patch
0007-Fix-compilation-error-on-FreeBSD.patch
0% Loading or .
You are about to add 0 people to the discussion. Proceed with caution.
Finish editing this message first!
Please register or to comment
diff --git a/CMakeModules/GenerateConfigScript.cmake b/CMakeModules/GenerateConfigScript.cmake
index cdcdf78..6200a06 100644
index cdcdf78..d30fe33 100644
--- a/CMakeModules/GenerateConfigScript.cmake
+++ b/CMakeModules/GenerateConfigScript.cmake
@@ -31,8 +31,12 @@
......@@ -59,7 +59,7 @@ index cdcdf78..6200a06 100644
# Description:
# This file generates the ViSP library config shell script: "visp-config"
# from visp-config.in (in VISP_SOURCE_DIR).
......@@ -194,7 +194,7 @@ index cdcdf78..6200a06 100644
+ set(exec_prefix "\${prefix}")
+ set(includedir "\${prefix}/${CMAKE_INSTALL_INCLUDEDIR}")
+ set(libdir "\${prefix}/${CMAKE_INSTALL_LIBDIR}")
+
+
+ # prepend with ViSP own include dir
+ set(VISP_CONFIG_CFLAGS_PC "-I\${includedir} ${VISP_CONFIG_CFLAGS}")
+
......@@ -209,7 +209,7 @@ index cdcdf78..6200a06 100644
ELSE(UNIX)
#######################################################################
@@ -309,3 +351,34 @@ ELSE(UNIX)
@@ -309,3 +351,32 @@ ELSE(UNIX)
CONFIGURE_FILE(${FILE_VISP_CONFIG_SCRIPT_IN} ${FILE_VISP_CONFIG_SCRIPT})
ENDIF(UNIX)
......@@ -242,8 +242,6 @@ index cdcdf78..6200a06 100644
+ELSE(UNIX)
+ # not implemented yet
+ENDIF (UNIX)
+
+
@@ -31,8 +31,12 @@
......@@ -59,7 +59,7 @@ index cdcdf78..6200a06 100644
# Description:
-# This file generates the ViSP library config shell script: "visp-config"
-# from visp-config.in (in VISP_SOURCE_DIR).
+# This file generates the ViSP library config shell scripts:
+# This file generates the ViSP library config shell scripts:
+# - visp-config in <build dir>/bin from visp-config.in
+# - visp-config in <build dir>/install from visp-config.install.in
+# When make install, this file is copied in <install dir>/bin
......@@ -194,7 +194,7 @@ index cdcdf78..6200a06 100644